katsdpmodels
============

Interfaces to access various models (such as sky models, primary beam models
and so on) for processing radio astronomy data. The actual models are not
stored here, just code.

Documentation is hosted at [readthedocs](https://katsdpmodels.readthedocs.io/).
